==> datapark-facade-1.2.20-sources.jar: com/bxm/datapark/facade/floatmaterial/model/vo/FloatMaterialCountVo.java <==
package com.bxm.datapark.facade.floatmaterial.model.vo;

import java.io.Serializable;

/**
 * 浮标素材统计实体
 * @author bcc
 */
public class FloatMaterialCountVo implements Serializable {

    /**
     * 业务日期
     */
    private String thedate;

    /**
     * 浮标素材ID
     */
    private String floatMtrId;

    private String appKey;

    private String business;

    /**
     * 广告位ID
     */
    private String positionId;

    /**
     * 浮标曝光量
     */
    private Integer exposurePv;

    /**
     * 点击量
     */
    private Integer clickPv;

    /**
     * 点击率
     */
    private Double clickRate;

    public String getThedate() {
        return thedate;
    }

    public void setThedate(String thedate) {
        this.thedate = thedate;
    }

    public String getFloatMtrId() {
        return floatMtrId;
    }

    public void setFloatMtrId(String floatMtrId) {
        this.floatMtrId = floatMtrId;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public Integer getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Integer exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Integer getClickPv() {
        return clickPv;
    }

    public void setClickPv(Integer clickPv) {
        this.clickPv = clickPv;
    }

    public Double getClickRate() {
        return clickRate;
    }

    public void setClickRate(Double clickRate) {
        this.clickRate = clickRate;
    }

}

==> datapark-facade-1.2.35-sources.jar: com/bxm/datapark/facade/floatmaterial/model/vo/FloatMaterialCountVo.java <==
package com.bxm.datapark.facade.floatmaterial.model.vo;

import java.io.Serializable;

/**
 * 浮标素材统计实体
 * @author bcc
 */
public class FloatMaterialCountVo implements Serializable {

    /**
     * 业务日期
     */
    private String thedate;

    /**
     * 浮标素材ID
     */
    private String floatMtrId;

    private String appKey;

    private String business;

    /**
     * 广告位ID
     */
    private String positionId;

    /**
     * 浮标曝光量
     */
    private Integer exposurePv;

    /**
     * 点击量
     */
    private Integer clickPv;

    /**
     * 点击率
     */
    private Double clickRate;

    /**
     * 浮标uv
     */
    private Integer exposureUv;

    private Integer clickUv;

    public String getThedate() {
        return thedate;
    }

    public void setThedate(String thedate) {
        this.thedate = thedate;
    }

    public String getFloatMtrId() {
        return floatMtrId;
    }

    public void setFloatMtrId(String floatMtrId) {
        this.floatMtrId = floatMtrId;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public Integer getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Integer exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Integer getClickPv() {
        return clickPv;
    }

    public void setClickPv(Integer clickPv) {
        this.clickPv = clickPv;
    }

    public Double getClickRate() {
        return clickRate;
    }

    public void setClickRate(Double clickRate) {
        this.clickRate = clickRate;
    }

    public Integer getExposureUv() {
        return exposureUv;
    }

    public void setExposureUv(Integer exposureUv) {
        this.exposureUv = exposureUv;
    }

    public Integer getClickUv() {
        return clickUv;
    }

    public void setClickUv(Integer clickUv) {
        this.clickUv = clickUv;
    }
}
